
############################################################################
#                 Webcalendar config file for debian                       #
#                                                                          #
# See /usr/share/doc/webcalendar/README.Debian for more information        #
#                                                                          #
############################################################################


############################################################################
# database settings                                                        #
############################################################################
db_type = DebConf::DB_TYPE
db_host = DebConf::DB_HOST
db_login = DebConf::DB_LOGIN
db_password = DebConf::DB_PASSWORD
db_database = DebConf::DB_DATABASE
db_persistent = DebConf::DB_PERSISTENT


############################################################################
# general configuration options                                            #
############################################################################

# is the calendar read only?
readonly = false

# is this a personal/single user calendar or not
single_user = DebConf::SINGLE_USER

# if single_user is true, what username should we use?
single_user_login = DebConf::SINGLE_USER_LOGIN

# do we use http authentication or allow webcalendar to handle auth?
use_http_auth = DebConf::USE_HTTP_AUTH

# which authentication mechanism will we be using?
# auth_mechanism can be standard (webcalendar database), ldap, nis or postnuke
# be sure the configuration for your chosen mechanism will work below
# if you choose anything besides standard, you'll need to configure that
# mechanism below
auth_mechanism = standard


############################################################################
# general user auth options                                                #
############################################################################
# if you use ldap auth mechanism these settings have no effect
# if you use nis or postnuke auth mechanism these should all be false as 
# nis and postnuke should be maintained external to webcalendar
# if you use standard auth mechanism set these to the desired value
user_can_update_password = true
admin_can_add_user = true
admin_can_delete_user = true


############################################################################
# ldap auth options                                                        #
############################################################################

ldap_server = localhost
ldap_port = 389

# use TLS for the connection (not the same as ldaps://)
ldap_start_tls = false

# openldap needs LDAP_OPT_PROTOCOL_VERSION set to 3
set_ldap_version = true
ldap_version = 3

# base search dn
ldap_base_dn = ou=People,dc=company,dc=com

# attribute used to find user (eg cn login is "Jane Smith", uid login might
# be "jsmith")
ldap_login_attr = uid

# Account used to bind to the server ad search for information.  This must
# have the correct rights to perform search.  If left empty the search will
# be done anonymously.  It is NOT recommended to store the root ldap
# account info here
ldap_admin_dn = 
ldap_admin_pwd = 

# group name to find users with admin rights
ldap_admin_group_name = cn=webcal_admin,ou=group,dc=company,dc=com

# what type of group do we want (posixgroup, groupofnames,
# groupofuniquenames)
ldap_admin_group_type = posixgroup

# the LDAP attribute used to store member of a group
ldap_admin_group_attr = memberuid

# ldap filter to find a user list
ldap_user_filter = (objectclass=person)

# attributes to fetch from ldap and corresponding user variables in the
# application. change to match your ldap schema
ldap_user_attr.login     = uid
ldap_user_attr.lastname  = sn
ldap_user_attr.firstname = givenname
ldap_user_attr.fullname  = cn
ldap_user_attr.email     = mail

############################################################################
# nis auth options                                                         #
############################################################################
# the domain for user email
user_external_email = 


############################################################################
# postnuke auth options                                                    #
############################################################################

# postnuke session id cookie
pn_sid = POSTNUKESID

# name of table containing users
pn_user_table = nuke_users

# name of table containing sessions
pn_session_table = nuke_session_info

# name of table containing group memberships
pn_group_table = nuke_group_membership

# name of table containing settings
pn_settings_table = nuke_module_vars

# set the group id of the postnuke group you want to be webcal admins
# default is the postnuke 'Admins' group
pn_admin_gid = 2

# what is the full url to the login page for postnuke?
app_login_page = http://www.mysite.com/postnuke/html/user.php?op=loginscreen&module=NS-User

# is there a parameter we can pass to tell the application to redirect the
# user back to the calendar after login?
app_redir_param = url

# what is the full url to the logout page?
app_logout_page = http://www.mysite.com/postnuke/html/user.php?module=NS-User&op=logout

# are the application's tables in the same database as webcalendar's?
app_same_db = false

#################################################
# these are only needed if app_same_db is false #
#################################################
# name of the database containing the postnuke tables
app_db = postnuke

# host that postnuke's db is on
app_host = localhost

# login & password to access the postnuke database
app_login = postnukeuser
app_pass  = postnukepass


